---
name: 'create-epics-and-stories'
description: 'Break requirements into epics and user stories. Use when the user says "create the epics and stories list"'
---

IT IS CRITICAL THAT YOU FOLLOW THIS COMMAND: LOAD the FULL {project-root}/_bmad/bmm/workflows/3-solutioning/create-epics-and-stories/workflow.md, READ its entire contents and follow its directions exactly!
